@@ -1006,7 +1006,7 @@ TEST(HelpersTest, AppendToStream)
       << std::setprecision(std::numeric_limits<long double>::digits10 + 1);
 
   math::appendToStream(out, pi);
-#ifdef _WIN32
+#if defined(_WIN32) && !defined(__amd64__) && !defined(__i386__)
   EXPECT_EQ(out.str(), "0 456 0 3.14159 3.141592654 3.141592653589793");
 #else
   EXPECT_EQ(out.str(), "0 456 0 3.14159 3.141592654 3.141592653589793239");
@@ -1016,7 +1016,7 @@ TEST(HelpersTest, AppendToStream)
       << std::setprecision(3);
 
   math::appendToStream(out, pi);
-#ifdef _WIN32
+#if defined(_WIN32) && !defined(__amd64__) && !defined(__i386__)
   EXPECT_EQ(out.str(), "0 456 0 3.14159 3.141592654 3.141592653589793 3.14");
 #else
   EXPECT_EQ(out.str(), "0 456 0 3.14159 3.141592654 3.141592653589793239 3.14");
